jactorch.functional.arith
=========================

.. automodule:: jactorch.functional.arith

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      atanh
      log_sigmoid
      logit
      soft_amax
      soft_amin
      tstat
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: atanh

.. autofunction:: log_sigmoid

.. autofunction:: logit

.. autofunction:: soft_amax

.. autofunction:: soft_amin

.. autofunction:: tstat


